import { TextMapPropagator, Context, TextMapSetter, TextMapGetter } from '@opentelemetry/api';
/**
 * This file implements propagation for the Stackdriver Trace v1 Trace Context
 * format.
 *
 * The header specification is:
 * "X-Cloud-Trace-Context: TRACE_ID/SPAN_ID;o=TRACE_TRUE"
 * Where:
 *  {TRACE_ID} is a 32-character hexadecimal value representing a 128-bit
 *    number. It should be unique between your requests, unless you
 *    intentionally want to bundle the requests together.
 *  {SPAN_ID} is the decimal representation of the (unsigned) span ID.
 *    It should be randomly generated and unique in your trace. For subsequent requests,
 *    set SPAN_ID to the span ID of the parent request.
 *  {TRACE_TRUE} must be 1 to trace request. Specify 0 to not trace the request.
 */
/** Header that carries span context across Google infrastructure. */
export declare const X_CLOUD_TRACE_HEADER = "x-cloud-trace-context";
export declare class CloudPropagator implements TextMapPropagator {
    inject(context: Context, carrier: unknown, setter: TextMapSetter<unknown>): void;
    extract(context: Context, carrier: unknown, getter: TextMapGetter<unknown>): Context;
    fields(): string[];
}
